Method: OvirtSDK4::StorageDomain#storage=

Defined in:
lib/ovirtsdk4/types.rb

#storage=(value) ⇒ Object

Sets the value of the storage attribute.

The value parameter can be an instance of HostStorage or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.



22642
22643
22644
22645
22646
22647
# File 'lib/ovirtsdk4/types.rb', line 22642

def storage=(value)
  if value.is_a?(Hash)
    value = HostStorage.new(value)
  end
  @storage = value
end