Method: OvirtSDK4::AssignedDiskProfilesService#list

Defined in:
lib/ovirtsdk4/services.rb

#list(opts = {}) ⇒ Array<DiskProfile>

Returns the list of disk profiles assigned to the storage domain.

The order of the returned disk profiles isn’t guaranteed.

Parameters:

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :follow (String)

    Indicates which inner links should be followed. The objects referenced by these links will be fetched as part of the current request. See here for details.

  • :max (Integer)

    Sets the maximum number of profiles to return. If not specified all the profiles are returned.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



2818
2819
2820
# File 'lib/ovirtsdk4/services.rb', line 2818

def list(opts = {})
  internal_get(LIST, opts)
end