Method: OvirtSDK4::ClusterEnabledFeaturesService#add

Defined in:
lib/ovirtsdk4/services.rb

#add(feature, opts = {}) ⇒ ClusterFeature

Enable an additional feature for a cluster.

For example, to enable a feature 456 on cluster 123, send a request like this:

POST /ovirt-engine/api/clusters/123/enabledfeatures HTTP/1.1

The request body should look like this:

<cluster_feature id="456"/>

Parameters:

  • feature (ClusterFeature)

    The feature to add.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



5193
5194
5195
# File 'lib/ovirtsdk4/services.rb', line 5193

def add(feature, opts = {})
  internal_add(feature, ClusterFeature, ADD, opts)
end