Method: OvirtSDK4::ClusterLevel#initialize

Defined in:
lib/ovirtsdk4/types.rb

#initialize(opts = {}) ⇒ ClusterLevel

Creates a new instance of the OvirtSDK4::ClusterLevel class.

Parameters:

  • opts (Hash) (defaults to: {})

    A hash containing the attributes of the object. The keys of the hash should be symbols corresponding to the names of the attributes. The values of the hash should be the values of the attributes.

Options Hash (opts):

  • :cluster_features (Array<ClusterFeature>, Array<Hash>)

    The values of attribute cluster_features.

  • :comment (String)

    The value of attribute comment.

  • :cpu_types (Array<CpuType>, Array<Hash>)

    The values of attribute cpu_types.

  • :description (String)

    The value of attribute description.

  • :id (String)

    The value of attribute id.

  • :name (String)

    The value of attribute name.

  • :permits (Array<Permit>, Array<Hash>)

    The values of attribute permits.



35397
35398
35399
35400
35401
35402
# File 'lib/ovirtsdk4/types.rb', line 35397

def initialize(opts = {})
  super(opts)
  self.cluster_features = opts[:cluster_features]
  self.cpu_types = opts[:cpu_types]
  self.permits = opts[:permits]
end