Method: OvirtSDK4::ClusterLevelsService#list

Defined in:
lib/ovirtsdk4/services.rb

#list(opts = {}) ⇒ Array<ClusterLevel>

Lists the cluster levels supported by the system.

GET /ovirt-engine/api/clusterlevels HTTP/1.1

This will return a list of available cluster levels.

<cluster_levels>
  <cluster_level id="4.0">
     ...
  </cluster_level>
  ...
</cluster_levels>

The order of the returned cluster levels isn’t guaranteed.

Parameters:

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :follow (String)

    Indicates which inner links should be followed. The objects referenced by these links will be fetched as part of the current request. See here for details.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



5597
5598
5599
# File 'lib/ovirtsdk4/services.rb', line 5597

def list(opts = {})
  internal_get(LIST, opts)
end