Method: OvirtSDK4::ClustersService#list
- Defined in:
- lib/ovirtsdk4/services.rb
#list(opts = {}) ⇒ Array<Cluster>
Returns the list of clusters of the system.
The order of the returned clusters is guaranteed only if the sortby clause is included in the
search parameter.
5334 5335 5336 |
# File 'lib/ovirtsdk4/services.rb', line 5334 def list(opts = {}) internal_get(LIST, opts) end |