Method: OvirtSDK4::FenceAgentService#update

Defined in:
lib/ovirtsdk4/services.rb

#update(agent, opts = {}) ⇒ Agent

Update a fencing-agent.

Parameters:

  • agent (Agent)

    Fence agent details.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :async (Boolean)

    Indicates if the update should be performed asynchronously.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



10384
10385
10386
# File 'lib/ovirtsdk4/services.rb', line 10384

def update(agent, opts = {})
  internal_update(agent, Agent, UPDATE, opts)
end