Method: OvirtSDK4::ImageTransferService#extend

Defined in:
lib/ovirtsdk4/services.rb

#extend(opts = {}) ⇒ Object

Extend the image transfer session.

Options Hash (opts):

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.



13130
13131
13132
# File 'lib/ovirtsdk4/services.rb', line 13130

def extend(opts = {})
  internal_action(:extend, nil, EXTEND, opts)
end