Method: OvirtSDK4::InstanceTypeGraphicsConsolesService#add

Defined in:
lib/ovirtsdk4/services.rb

#add(console, opts = {}) ⇒ GraphicsConsole

Add new graphics console to the instance type.

Parameters:

  • console (GraphicsConsole)

    The console to add.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



13830
13831
13832
# File 'lib/ovirtsdk4/services.rb', line 13830

def add(console, opts = {})
  internal_add(console, GraphicsConsole, ADD, opts)
end