Method: OvirtSDK4::InstanceTypesService#list

Defined in:
lib/ovirtsdk4/services.rb

#list(opts = {}) ⇒ Array<InstanceType>

Lists all existing instance types in the system.

The order of the returned list of instance types isn’t guaranteed.

Parameters:

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :case_sensitive (Boolean)

    Indicates if the search performed using the search parameter should be performed taking case into account. The default value is true, which means that case is taken into account. If you want to search ignoring case set it to false.

  • :follow (String)

    Indicates which inner links should be followed. The objects referenced by these links will be fetched as part of the current request. See here for details.

  • :max (Integer)

    Sets the maximum number of instance types to return. If not specified all the instance types are returned.

  • :search (String)

    A query string used to restrict the returned templates.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



14445
14446
14447
# File 'lib/ovirtsdk4/services.rb', line 14445

def list(opts = {})
  internal_get(LIST, opts)
end