Method: OvirtSDK4::Mac#initialize

Defined in:
lib/ovirtsdk4/types.rb

#initialize(opts = {}) ⇒ Mac

Creates a new instance of the OvirtSDK4::Mac class.

Parameters:

  • opts (Hash) (defaults to: {})

    A hash containing the attributes of the object. The keys of the hash should be symbols corresponding to the names of the attributes. The values of the hash should be the values of the attributes.

Options Hash (opts):

  • :address (String)

    The value of attribute address.



9592
9593
9594
9595
# File 'lib/ovirtsdk4/types.rb', line 9592

def initialize(opts = {})
  super(opts)
  self.address = opts[:address]
end