Method: OvirtSDK4::MemoryPolicy#initialize

Defined in:
lib/ovirtsdk4/types.rb

#initialize(opts = {}) ⇒ MemoryPolicy

Creates a new instance of the OvirtSDK4::MemoryPolicy class.

Parameters:

  • opts (Hash) (defaults to: {})

    A hash containing the attributes of the object. The keys of the hash should be symbols corresponding to the names of the attributes. The values of the hash should be the values of the attributes.

Options Hash (opts):

  • :ballooning (Boolean)

    The value of attribute ballooning.

  • :guaranteed (Integer)

    The value of attribute guaranteed.

  • :max (Integer)

    The value of attribute max.

  • :over_commit (MemoryOverCommit, Hash)

    The value of attribute over_commit.

  • :transparent_huge_pages (TransparentHugePages, Hash)

    The value of attribute transparent_huge_pages.



10010
10011
10012
10013
10014
10015
10016
10017
# File 'lib/ovirtsdk4/types.rb', line 10010

def initialize(opts = {})
  super(opts)
  self.ballooning = opts[:ballooning]
  self.guaranteed = opts[:guaranteed]
  self.max = opts[:max]
  self.over_commit = opts[:over_commit]
  self.transparent_huge_pages = opts[:transparent_huge_pages]
end