Method: OvirtSDK4::NetworkAttachmentService#update

Defined in:
lib/ovirtsdk4/services.rb

#update(attachment, opts = {}) ⇒ NetworkAttachment

Update the specified network attachment on the host.

Parameters:

  • attachment (NetworkAttachment)

    The attachment to update.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :async (Boolean)

    Indicates if the update should be performed asynchronously.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



15955
15956
15957
# File 'lib/ovirtsdk4/services.rb', line 15955

def update(attachment, opts = {})
  internal_update(attachment, NetworkAttachment, UPDATE, opts)
end