Method: OvirtSDK4::OpenStackImage#openstack_image_provider=

Defined in:
lib/ovirtsdk4/types.rb

#openstack_image_provider=(value) ⇒ Object

Sets the value of the openstack_image_provider attribute.

The value parameter can be an instance of OvirtSDK4::OpenStackImageProvider or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.

Parameters:



12796
12797
12798
12799
12800
12801
# File 'lib/ovirtsdk4/types.rb', line 12796

def openstack_image_provider=(value)
  if value.is_a?(Hash)
    value = OpenStackImageProvider.new(value)
  end
  @openstack_image_provider = value
end