Class: OvirtSDK4::OpenStackNetworkProvider

Inherits:
OpenStackProvider show all
Defined in:
lib/ovirtsdk4/types.rb,
lib/ovirtsdk4/types.rb

Instance Method Summary collapse

Methods included from Type

#dig, #href, #href=

Constructor Details

#initialize(opts = {}) ⇒ OpenStackNetworkProvider

Creates a new instance of the OvirtSDK4::OpenStackNetworkProvider class.

Options Hash (opts):

  • :agent_configuration (AgentConfiguration, Hash)

    The value of attribute agent_configuration.

  • :authentication_url (String)

    The value of attribute authentication_url.

  • :auto_sync (Boolean)

    The value of attribute auto_sync.

  • :certificates (Array<Certificate>, Array<Hash>)

    The values of attribute certificates.

  • :comment (String)

    The value of attribute comment.

  • :description (String)

    The value of attribute description.

  • :external_plugin_type (String)

    The value of attribute external_plugin_type.

  • :id (String)

    The value of attribute id.

  • :name (String)

    The value of attribute name.

  • :networks (Array<OpenStackNetwork>, Array<Hash>)

    The values of attribute networks.

  • :password (String)

    The value of attribute password.

  • :plugin_type (NetworkPluginType)

    The value of attribute plugin_type.

  • :project_domain_name (String)

    The value of attribute project_domain_name.

  • :project_name (String)

    The value of attribute project_name.

  • :properties (Array<Property>, Array<Hash>)

    The values of attribute properties.

  • :read_only (Boolean)

    The value of attribute read_only.

  • :requires_authentication (Boolean)

    The value of attribute requires_authentication.

  • :subnets (Array<OpenStackSubnet>, Array<Hash>)

    The values of attribute subnets.

  • :tenant_name (String)

    The value of attribute tenant_name.

  • :type (OpenStackNetworkProviderType)

    The value of attribute type.

  • :unmanaged (Boolean)

    The value of attribute unmanaged.

  • :url (String)

    The value of attribute url.

  • :user_domain_name (String)

    The value of attribute user_domain_name.

  • :username (String)

    The value of attribute username.



57522
57523
57524
57525
57526
57527
57528
57529
57530
57531
57532
57533
57534
57535
57536
57537
# File 'lib/ovirtsdk4/types.rb', line 57522

def initialize(opts = {})
  super(opts)
  self.agent_configuration = opts[:agent_configuration]
  self.auto_sync = opts[:auto_sync]
  self.certificates = opts[:certificates]
  self.external_plugin_type = opts[:external_plugin_type]
  self.networks = opts[:networks]
  self.plugin_type = opts[:plugin_type]
  self.project_domain_name = opts[:project_domain_name]
  self.project_name = opts[:project_name]
  self.read_only = opts[:read_only]
  self.subnets = opts[:subnets]
  self.type = opts[:type]
  self.unmanaged = opts[:unmanaged]
  self.user_domain_name = opts[:user_domain_name]
end

Instance Method Details

#==(other) ⇒ Object

Returns true if self and other have the same attributes and values.



57542
57543
57544
57545
57546
57547
57548
57549
57550
57551
57552
57553
57554
57555
57556
57557
# File 'lib/ovirtsdk4/types.rb', line 57542

def ==(other)
  super &&
  @agent_configuration == other.agent_configuration &&
  @auto_sync == other.auto_sync &&
  @certificates == other.certificates &&
  @external_plugin_type == other.external_plugin_type &&
  @networks == other.networks &&
  @plugin_type == other.plugin_type &&
  @project_domain_name == other.project_domain_name &&
  @project_name == other.project_name &&
  @read_only == other.read_only &&
  @subnets == other.subnets &&
  @type == other.type &&
  @unmanaged == other.unmanaged &&
  @user_domain_name == other.user_domain_name
end

#agent_configurationAgentConfiguration

Returns the value of the agent_configuration attribute.



57000
57001
57002
# File 'lib/ovirtsdk4/types.rb', line 57000

def agent_configuration
  @agent_configuration
end

#agent_configuration=(value) ⇒ Object

Sets the value of the agent_configuration attribute.

The value parameter can be an instance of AgentConfiguration or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.



57013
57014
57015
57016
57017
57018
# File 'lib/ovirtsdk4/types.rb', line 57013

def agent_configuration=(value)
  if value.is_a?(Hash)
    value = AgentConfiguration.new(value)
  end
  @agent_configuration = value
end

#authentication_urlString

Returns the value of the authentication_url attribute.



57025
57026
57027
# File 'lib/ovirtsdk4/types.rb', line 57025

def authentication_url
  @authentication_url
end

#authentication_url=(value) ⇒ Object

Sets the value of the authentication_url attribute.



57034
57035
57036
# File 'lib/ovirtsdk4/types.rb', line 57034

def authentication_url=(value)
  @authentication_url = value
end

#auto_syncBoolean

Returns the value of the auto_sync attribute.



57043
57044
57045
# File 'lib/ovirtsdk4/types.rb', line 57043

def auto_sync
  @auto_sync
end

#auto_sync=(value) ⇒ Object

Sets the value of the auto_sync attribute.



57052
57053
57054
# File 'lib/ovirtsdk4/types.rb', line 57052

def auto_sync=(value)
  @auto_sync = value
end

#certificatesArray<Certificate>

Returns the value of the certificates attribute.



57061
57062
57063
# File 'lib/ovirtsdk4/types.rb', line 57061

def certificates
  @certificates
end

#certificates=(list) ⇒ Object

Sets the value of the certificates attribute.



57070
57071
57072
57073
57074
57075
57076
57077
57078
57079
57080
# File 'lib/ovirtsdk4/types.rb', line 57070

def certificates=(list)
  if list.class == Array
    list = List.new(list)
    list.each_with_index do |value, index|
      if value.is_a?(Hash)
        list[index] = Certificate.new(value)
      end
    end
  end
  @certificates = list
end

#commentString

Returns the value of the comment attribute.



57087
57088
57089
# File 'lib/ovirtsdk4/types.rb', line 57087

def comment
  @comment
end

#comment=(value) ⇒ Object

Sets the value of the comment attribute.



57096
57097
57098
# File 'lib/ovirtsdk4/types.rb', line 57096

def comment=(value)
  @comment = value
end

#descriptionString

Returns the value of the description attribute.



57105
57106
57107
# File 'lib/ovirtsdk4/types.rb', line 57105

def description
  @description
end

#description=(value) ⇒ Object

Sets the value of the description attribute.



57114
57115
57116
# File 'lib/ovirtsdk4/types.rb', line 57114

def description=(value)
  @description = value
end

#external_plugin_typeString

Returns the value of the external_plugin_type attribute.



57123
57124
57125
# File 'lib/ovirtsdk4/types.rb', line 57123

def external_plugin_type
  @external_plugin_type
end

#external_plugin_type=(value) ⇒ Object

Sets the value of the external_plugin_type attribute.



57132
57133
57134
# File 'lib/ovirtsdk4/types.rb', line 57132

def external_plugin_type=(value)
  @external_plugin_type = value
end

#hashObject

Generates a hash value for this object.



57562
57563
57564
57565
57566
57567
57568
57569
57570
57571
57572
57573
57574
57575
57576
57577
# File 'lib/ovirtsdk4/types.rb', line 57562

def hash
  super +
  @agent_configuration.hash +
  @auto_sync.hash +
  @certificates.hash +
  @external_plugin_type.hash +
  @networks.hash +
  @plugin_type.hash +
  @project_domain_name.hash +
  @project_name.hash +
  @read_only.hash +
  @subnets.hash +
  @type.hash +
  @unmanaged.hash +
  @user_domain_name.hash
end

#idString

Returns the value of the id attribute.



57141
57142
57143
# File 'lib/ovirtsdk4/types.rb', line 57141

def id
  @id
end

#id=(value) ⇒ Object

Sets the value of the id attribute.



57150
57151
57152
# File 'lib/ovirtsdk4/types.rb', line 57150

def id=(value)
  @id = value
end

#nameString

Returns the value of the name attribute.



57159
57160
57161
# File 'lib/ovirtsdk4/types.rb', line 57159

def name
  @name
end

#name=(value) ⇒ Object

Sets the value of the name attribute.



57168
57169
57170
# File 'lib/ovirtsdk4/types.rb', line 57168

def name=(value)
  @name = value
end

#networksArray<OpenStackNetwork>

Returns the value of the networks attribute.



57177
57178
57179
# File 'lib/ovirtsdk4/types.rb', line 57177

def networks
  @networks
end

#networks=(list) ⇒ Object

Sets the value of the networks attribute.



57186
57187
57188
57189
57190
57191
57192
57193
57194
57195
57196
# File 'lib/ovirtsdk4/types.rb', line 57186

def networks=(list)
  if list.class == Array
    list = List.new(list)
    list.each_with_index do |value, index|
      if value.is_a?(Hash)
        list[index] = OpenStackNetwork.new(value)
      end
    end
  end
  @networks = list
end

#passwordString

Returns the value of the password attribute.



57203
57204
57205
# File 'lib/ovirtsdk4/types.rb', line 57203

def password
  @password
end

#password=(value) ⇒ Object

Sets the value of the password attribute.



57212
57213
57214
# File 'lib/ovirtsdk4/types.rb', line 57212

def password=(value)
  @password = value
end

#plugin_typeNetworkPluginType

Returns the value of the plugin_type attribute.



57221
57222
57223
# File 'lib/ovirtsdk4/types.rb', line 57221

def plugin_type
  @plugin_type
end

#plugin_type=(value) ⇒ Object

Sets the value of the plugin_type attribute.



57230
57231
57232
# File 'lib/ovirtsdk4/types.rb', line 57230

def plugin_type=(value)
  @plugin_type = value
end

#project_domain_nameString

Returns the value of the project_domain_name attribute.



57239
57240
57241
# File 'lib/ovirtsdk4/types.rb', line 57239

def project_domain_name
  @project_domain_name
end

#project_domain_name=(value) ⇒ Object

Sets the value of the project_domain_name attribute.



57248
57249
57250
# File 'lib/ovirtsdk4/types.rb', line 57248

def project_domain_name=(value)
  @project_domain_name = value
end

#project_nameString

Returns the value of the project_name attribute.



57257
57258
57259
# File 'lib/ovirtsdk4/types.rb', line 57257

def project_name
  @project_name
end

#project_name=(value) ⇒ Object

Sets the value of the project_name attribute.



57266
57267
57268
# File 'lib/ovirtsdk4/types.rb', line 57266

def project_name=(value)
  @project_name = value
end

#propertiesArray<Property>

Returns the value of the properties attribute.



57275
57276
57277
# File 'lib/ovirtsdk4/types.rb', line 57275

def properties
  @properties
end

#properties=(list) ⇒ Object

Sets the value of the properties attribute.



57284
57285
57286
57287
57288
57289
57290
57291
57292
57293
57294
# File 'lib/ovirtsdk4/types.rb', line 57284

def properties=(list)
  if list.class == Array
    list = List.new(list)
    list.each_with_index do |value, index|
      if value.is_a?(Hash)
        list[index] = Property.new(value)
      end
    end
  end
  @properties = list
end

#read_onlyBoolean

Returns the value of the read_only attribute.



57301
57302
57303
# File 'lib/ovirtsdk4/types.rb', line 57301

def read_only
  @read_only
end

#read_only=(value) ⇒ Object

Sets the value of the read_only attribute.



57310
57311
57312
# File 'lib/ovirtsdk4/types.rb', line 57310

def read_only=(value)
  @read_only = value
end

#requires_authenticationBoolean

Returns the value of the requires_authentication attribute.



57319
57320
57321
# File 'lib/ovirtsdk4/types.rb', line 57319

def requires_authentication
  @requires_authentication
end

#requires_authentication=(value) ⇒ Object

Sets the value of the requires_authentication attribute.



57328
57329
57330
# File 'lib/ovirtsdk4/types.rb', line 57328

def requires_authentication=(value)
  @requires_authentication = value
end

#subnetsArray<OpenStackSubnet>

Returns the value of the subnets attribute.



57337
57338
57339
# File 'lib/ovirtsdk4/types.rb', line 57337

def subnets
  @subnets
end

#subnets=(list) ⇒ Object

Sets the value of the subnets attribute.



57346
57347
57348
57349
57350
57351
57352
57353
57354
57355
57356
# File 'lib/ovirtsdk4/types.rb', line 57346

def subnets=(list)
  if list.class == Array
    list = List.new(list)
    list.each_with_index do |value, index|
      if value.is_a?(Hash)
        list[index] = OpenStackSubnet.new(value)
      end
    end
  end
  @subnets = list
end

#tenant_nameString

Returns the value of the tenant_name attribute.



57363
57364
57365
# File 'lib/ovirtsdk4/types.rb', line 57363

def tenant_name
  @tenant_name
end

#tenant_name=(value) ⇒ Object

Sets the value of the tenant_name attribute.



57372
57373
57374
# File 'lib/ovirtsdk4/types.rb', line 57372

def tenant_name=(value)
  @tenant_name = value
end

#typeOpenStackNetworkProviderType

Returns the value of the type attribute.



57381
57382
57383
# File 'lib/ovirtsdk4/types.rb', line 57381

def type
  @type
end

#type=(value) ⇒ Object

Sets the value of the type attribute.



57390
57391
57392
# File 'lib/ovirtsdk4/types.rb', line 57390

def type=(value)
  @type = value
end

#unmanagedBoolean

Returns the value of the unmanaged attribute.



57399
57400
57401
# File 'lib/ovirtsdk4/types.rb', line 57399

def unmanaged
  @unmanaged
end

#unmanaged=(value) ⇒ Object

Sets the value of the unmanaged attribute.



57408
57409
57410
# File 'lib/ovirtsdk4/types.rb', line 57408

def unmanaged=(value)
  @unmanaged = value
end

#urlString

Returns the value of the url attribute.



57417
57418
57419
# File 'lib/ovirtsdk4/types.rb', line 57417

def url
  @url
end

#url=(value) ⇒ Object

Sets the value of the url attribute.



57426
57427
57428
# File 'lib/ovirtsdk4/types.rb', line 57426

def url=(value)
  @url = value
end

#user_domain_nameString

Returns the value of the user_domain_name attribute.



57435
57436
57437
# File 'lib/ovirtsdk4/types.rb', line 57435

def user_domain_name
  @user_domain_name
end

#user_domain_name=(value) ⇒ Object

Sets the value of the user_domain_name attribute.



57444
57445
57446
# File 'lib/ovirtsdk4/types.rb', line 57444

def user_domain_name=(value)
  @user_domain_name = value
end

#usernameString

Returns the value of the username attribute.



57453
57454
57455
# File 'lib/ovirtsdk4/types.rb', line 57453

def username
  @username
end

#username=(value) ⇒ Object

Sets the value of the username attribute.



57462
57463
57464
# File 'lib/ovirtsdk4/types.rb', line 57462

def username=(value)
  @username = value
end