Method: OvirtSDK4::OpenStackNetworkProvider#agent_configuration=

Defined in:
lib/ovirtsdk4/types.rb

#agent_configuration=(value) ⇒ Object

Sets the value of the agent_configuration attribute.

The value parameter can be an instance of AgentConfiguration or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.



57013
57014
57015
57016
57017
57018
# File 'lib/ovirtsdk4/types.rb', line 57013

def agent_configuration=(value)
  if value.is_a?(Hash)
    value = AgentConfiguration.new(value)
  end
  @agent_configuration = value
end