Method: OvirtSDK4::OperatingSystem#version=

Defined in:
lib/ovirtsdk4/types.rb

#version=(value) ⇒ Object

Sets the value of the version attribute.

The value parameter can be an instance of Version or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.

Parameters:



13790
13791
13792
13793
13794
13795
# File 'lib/ovirtsdk4/types.rb', line 13790

def version=(value)
  if value.is_a?(Hash)
    value = Version.new(value)
  end
  @version = value
end