Method: OvirtSDK4::RegistrationVnicProfileMapping#initialize

Defined in:
lib/ovirtsdk4/types.rb

#initialize(opts = {}) ⇒ RegistrationVnicProfileMapping

Creates a new instance of the OvirtSDK4::RegistrationVnicProfileMapping class.

Parameters:

  • opts (Hash) (defaults to: {})

    A hash containing the attributes of the object. The keys of the hash should be symbols corresponding to the names of the attributes. The values of the hash should be the values of the attributes.

Options Hash (opts):

  • :from (VnicProfile, Hash)

    The value of attribute from.

  • :to (VnicProfile, Hash)

    The value of attribute to.



18277
18278
18279
18280
18281
# File 'lib/ovirtsdk4/types.rb', line 18277

def initialize(opts = {})
  super(opts)
  self.from = opts[:from]
  self.to = opts[:to]
end