Class: OvirtSDK4::RngDevice

Inherits:
Struct
  • Object
show all
Defined in:
lib/ovirtsdk4/types.rb,
lib/ovirtsdk4/types.rb

Instance Method Summary collapse

Methods included from Type

#dig, #href, #href=

Constructor Details

#initialize(opts = {}) ⇒ RngDevice

Creates a new instance of the OvirtSDK4::RngDevice class.

Options Hash (opts):

  • :rate (Rate, Hash)

    The value of attribute rate.

  • :source (RngSource)

    The value of attribute source.



18706
18707
18708
18709
18710
# File 'lib/ovirtsdk4/types.rb', line 18706

def initialize(opts = {})
  super(opts)
  self.rate = opts[:rate]
  self.source = opts[:source]
end

Instance Method Details

#==(other) ⇒ Object

Returns true if self and other have the same attributes and values.



18715
18716
18717
18718
18719
# File 'lib/ovirtsdk4/types.rb', line 18715

def ==(other)
  super &&
  @rate == other.rate &&
  @source == other.source
end

#hashObject

Generates a hash value for this object.



18724
18725
18726
18727
18728
# File 'lib/ovirtsdk4/types.rb', line 18724

def hash
  super +
  @rate.hash +
  @source.hash
end

#rateRate

Returns the value of the rate attribute.



18656
18657
18658
# File 'lib/ovirtsdk4/types.rb', line 18656

def rate
  @rate
end

#rate=(value) ⇒ Object

Sets the value of the rate attribute.

The value parameter can be an instance of OvirtSDK4::Rate or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.



18669
18670
18671
18672
18673
18674
# File 'lib/ovirtsdk4/types.rb', line 18669

def rate=(value)
  if value.is_a?(Hash)
    value = Rate.new(value)
  end
  @rate = value
end

#sourceRngSource

Returns the value of the source attribute.



18681
18682
18683
# File 'lib/ovirtsdk4/types.rb', line 18681

def source
  @source
end

#source=(value) ⇒ Object

Sets the value of the source attribute.



18690
18691
18692
# File 'lib/ovirtsdk4/types.rb', line 18690

def source=(value)
  @source = value
end