Method: OvirtSDK4::SchedulingPolicyUnit#initialize

Defined in:
lib/ovirtsdk4/types.rb

#initialize(opts = {}) ⇒ SchedulingPolicyUnit

Creates a new instance of the OvirtSDK4::SchedulingPolicyUnit class.

Parameters:

  • opts (Hash) (defaults to: {})

    A hash containing the attributes of the object. The keys of the hash should be symbols corresponding to the names of the attributes. The values of the hash should be the values of the attributes.

Options Hash (opts):

  • :comment (String)

    The value of attribute comment.

  • :description (String)

    The value of attribute description.

  • :enabled (Boolean)

    The value of attribute enabled.

  • :id (String)

    The value of attribute id.

  • :internal (Boolean)

    The value of attribute internal.

  • :name (String)

    The value of attribute name.

  • :properties (Array<Property>, Array<Hash>)

    The values of attribute properties.

  • :type (PolicyUnitType)

    The value of attribute type.



19407
19408
19409
19410
19411
19412
19413
# File 'lib/ovirtsdk4/types.rb', line 19407

def initialize(opts = {})
  super(opts)
  self.enabled = opts[:enabled]
  self.internal = opts[:internal]
  self.properties = opts[:properties]
  self.type = opts[:type]
end