Class: OvirtSDK4::Ssh

Inherits:
Identified show all
Defined in:
lib/ovirtsdk4/types.rb,
lib/ovirtsdk4/types.rb

Instance Method Summary collapse

Methods included from Type

#dig, #href, #href=

Constructor Details

#initialize(opts = {}) ⇒ Ssh

Creates a new instance of the OvirtSDK4::Ssh class.

Options Hash (opts):

  • :authentication_method (SshAuthenticationMethod)

    The value of attribute authentication_method.

  • :comment (String)

    The value of attribute comment.

  • :description (String)

    The value of attribute description.

  • :fingerprint (String)

    The value of attribute fingerprint.

  • :id (String)

    The value of attribute id.

  • :name (String)

    The value of attribute name.

  • :port (Integer)

    The value of attribute port.

  • :public_key (String)

    The value of attribute public_key.

  • :user (User, Hash)

    The value of attribute user.



20306
20307
20308
20309
20310
20311
20312
20313
# File 'lib/ovirtsdk4/types.rb', line 20306

def initialize(opts = {})
  super(opts)
  self.authentication_method = opts[:authentication_method]
  self.fingerprint = opts[:fingerprint]
  self.port = opts[:port]
  self.public_key = opts[:public_key]
  self.user = opts[:user]
end

Instance Method Details

#==(other) ⇒ Object

Returns true if self and other have the same attributes and values.



20318
20319
20320
20321
20322
20323
20324
20325
# File 'lib/ovirtsdk4/types.rb', line 20318

def ==(other)
  super &&
  @authentication_method == other.authentication_method &&
  @fingerprint == other.fingerprint &&
  @port == other.port &&
  @public_key == other.public_key &&
  @user == other.user
end

#authentication_methodSshAuthenticationMethod

Returns the value of the authentication_method attribute.



20116
20117
20118
# File 'lib/ovirtsdk4/types.rb', line 20116

def authentication_method
  @authentication_method
end

#authentication_method=(value) ⇒ Object

Sets the value of the authentication_method attribute.



20125
20126
20127
# File 'lib/ovirtsdk4/types.rb', line 20125

def authentication_method=(value)
  @authentication_method = value
end

#commentString

Returns the value of the comment attribute.



20134
20135
20136
# File 'lib/ovirtsdk4/types.rb', line 20134

def comment
  @comment
end

#comment=(value) ⇒ Object

Sets the value of the comment attribute.



20143
20144
20145
# File 'lib/ovirtsdk4/types.rb', line 20143

def comment=(value)
  @comment = value
end

#descriptionString

Returns the value of the description attribute.



20152
20153
20154
# File 'lib/ovirtsdk4/types.rb', line 20152

def description
  @description
end

#description=(value) ⇒ Object

Sets the value of the description attribute.



20161
20162
20163
# File 'lib/ovirtsdk4/types.rb', line 20161

def description=(value)
  @description = value
end

#fingerprintString

Returns the value of the fingerprint attribute.



20170
20171
20172
# File 'lib/ovirtsdk4/types.rb', line 20170

def fingerprint
  @fingerprint
end

#fingerprint=(value) ⇒ Object

Sets the value of the fingerprint attribute.



20179
20180
20181
# File 'lib/ovirtsdk4/types.rb', line 20179

def fingerprint=(value)
  @fingerprint = value
end

#hashObject

Generates a hash value for this object.



20330
20331
20332
20333
20334
20335
20336
20337
# File 'lib/ovirtsdk4/types.rb', line 20330

def hash
  super +
  @authentication_method.hash +
  @fingerprint.hash +
  @port.hash +
  @public_key.hash +
  @user.hash
end

#idString

Returns the value of the id attribute.



20188
20189
20190
# File 'lib/ovirtsdk4/types.rb', line 20188

def id
  @id
end

#id=(value) ⇒ Object

Sets the value of the id attribute.



20197
20198
20199
# File 'lib/ovirtsdk4/types.rb', line 20197

def id=(value)
  @id = value
end

#nameString

Returns the value of the name attribute.



20206
20207
20208
# File 'lib/ovirtsdk4/types.rb', line 20206

def name
  @name
end

#name=(value) ⇒ Object

Sets the value of the name attribute.



20215
20216
20217
# File 'lib/ovirtsdk4/types.rb', line 20215

def name=(value)
  @name = value
end

#portInteger

Returns the value of the port attribute.



20224
20225
20226
# File 'lib/ovirtsdk4/types.rb', line 20224

def port
  @port
end

#port=(value) ⇒ Object

Sets the value of the port attribute.



20233
20234
20235
# File 'lib/ovirtsdk4/types.rb', line 20233

def port=(value)
  @port = value
end

#public_keyString

Returns the value of the public_key attribute.



20242
20243
20244
# File 'lib/ovirtsdk4/types.rb', line 20242

def public_key
  @public_key
end

#public_key=(value) ⇒ Object

Sets the value of the public_key attribute.



20251
20252
20253
# File 'lib/ovirtsdk4/types.rb', line 20251

def public_key=(value)
  @public_key = value
end

#userUser

Returns the value of the user attribute.



20260
20261
20262
# File 'lib/ovirtsdk4/types.rb', line 20260

def user
  @user
end

#user=(value) ⇒ Object

Sets the value of the user attribute.

The value parameter can be an instance of User or a hash. If it is a hash then a new instance will be created passing the hash as the opts parameter to the constructor.



20273
20274
20275
20276
20277
20278
# File 'lib/ovirtsdk4/types.rb', line 20273

def user=(value)
  if value.is_a?(Hash)
    value = User.new(value)
  end
  @user = value
end