Method: OvirtSDK4::StorageDomainsService#list
- Defined in:
- lib/ovirtsdk4/services.rb
#list(opts = {}) ⇒ Array<StorageDomain>
Returns the list of storage domains in the system.
The order of the returned list of storage domains is guaranteed only if the sortby clause is included
in the search parameter.
23310 23311 23312 |
# File 'lib/ovirtsdk4/services.rb', line 23310 def list(opts = {}) internal_get(LIST, opts) end |