Method: OvirtSDK4::StorageServerConnectionService#update_local

Defined in:
lib/ovirtsdk4/services.rb

#update_local(connection, opts = {}) ⇒ StorageConnection

Update the specified local storage connection in the system.

Parameters:

  • connection (StorageConnection)

    The connection to update.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :async (Boolean)

    Indicates if the update should be performed asynchronously.

  • :force (Boolean)

    Indicates if the operation should succeed regardless to the relevant storage domain’s status (i.e. updating is also applicable when storage domain’s status is not maintenance).

    This parameter is optional, and the default value is false.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



24433
24434
24435
# File 'lib/ovirtsdk4/services.rb', line 24433

def update_local(connection, opts = {})
  internal_update(connection, StorageConnection, UPDATE_LOCAL, opts)
end