Method: OvirtSDK4::UserService#update

Defined in:
lib/ovirtsdk4/services.rb

#update(user, opts = {}) ⇒ User

Updates information about the user.

Only the user_options field can be updated.

For example, to update user options:

PUT /ovirt-engine/api/users/123 HTTP/1.1

With a request body like this:

<user>
   <user_options>
      <property>
         <name>test</name>
         <value>["any","JSON"]</value>
      </property>
   </user_options>
</user>
Important
Since version 4.4.5 of the engine this operation is deprecated, and preserved only for backwards compatibility. It will be removed in the future. Please use the options endpoint instead.

Parameters:

  • user (User)

    The user to update.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



29100
29101
29102
# File 'lib/ovirtsdk4/services.rb', line 29100

def update(user, opts = {})
  internal_update(user, User, UPDATE, opts)
end