Method: OvirtSDK4::VirtualFunctionAllowedNetworksService#add

Defined in:
lib/ovirtsdk4/services.rb

#add(network, opts = {}) ⇒ Network

Adds a new network.

Parameters:

  • network (Network)

    The network to add.

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.

Returns:



29692
29693
29694
# File 'lib/ovirtsdk4/services.rb', line 29692

def add(network, opts = {})
  internal_add(network, Network, ADD, opts)
end