Method: OvirtSDK4::VmGraphicsConsoleService#ticket

Defined in:
lib/ovirtsdk4/services.rb

#ticket(opts = {}) ⇒ Object

Generates a time-sensitive authentication token for accessing this virtual machine’s console.

POST /ovirt-engine/api/vms/123/graphicsconsoles/456/ticket HTTP/1.1

The client-provided action optionally includes a desired ticket value and/or an expiry time in seconds.

In any case, the response specifies the actual ticket value and expiry used.

<action>
  <ticket>
    <value>abcd12345</value>
    <expiry>120</expiry>
  </ticket>
</action>

Parameters:

  • opts (Hash) (defaults to: {})

    Additional options.

Options Hash (opts):

  • :ticket (Ticket)

    The generated ticket that can be used to access this console.

  • :headers (Hash) — default: {}

    Additional HTTP headers.

  • :query (Hash) — default: {}

    Additional URL query parameters.

  • :timeout (Integer) — default: nil

    The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.

  • :wait (Boolean) — default: true

    If true wait for the response.



33021
33022
33023
# File 'lib/ovirtsdk4/services.rb', line 33021

def ticket(opts = {})
  internal_action(:ticket, :ticket, TICKET, opts)
end