Method: OvirtSDK4::VmService#start
- Defined in:
- lib/ovirtsdk4/services.rb
#start(opts = {}) ⇒ Object
Starts the virtual machine.
If the virtual environment is complete and the virtual machine contains all necessary components to function, it can be started.
This example starts the virtual machine:
POST /ovirt-engine/api/vms/123/start
With a request body:
<action/>
29016 29017 29018 |
# File 'lib/ovirtsdk4/services.rb', line 29016 def start(opts = {}) internal_action(:start, nil, START, opts) end |