Method: OvirtSDK4::ExternalHostGroupsService#list
- Defined in:
- lib/ovirtsdk4/services.rb
#list(opts = {}) ⇒ Array<ExternalHostGroup>
Get host groups list from external host provider.
Host group is a term of host providers - the host group includes provision details. This API returns all possible hostgroups exposed by the external provider.
For example, to get the details of all host groups of provider 123, send a request like this:
GET /ovirt-engine/api/externalhostproviders/123/hostgroups HTTP/1.1
The response will be like this:
<external_host_groups>
<external_host_group href="/ovirt-engine/api/externalhostproviders/123/hostgroups/234" id="234">
<name>rhel7</name>
<architecture_name>x86_64</architecture_name>
<domain_name>example.com</domain_name>
<operating_system_name>RedHat 7.3</operating_system_name>
<subnet_name>sat0</subnet_name>
<external_host_provider href="/ovirt-engine/api/externalhostproviders/123" id="123"/>
</external_host_group>
...
</external_host_groups>
The order of the returned list of host groups isn’t guaranteed.
9603 9604 9605 |
# File 'lib/ovirtsdk4/services.rb', line 9603 def list(opts = {}) internal_get(LIST, opts) end |