Update a fencing-agent.
Parameters:
Fence agent details.
Additional options.
Options Hash (opts):
Indicates if the update should be performed asynchronously.
Additional HTTP headers.
Additional URL query parameters.
The timeout for this request, in seconds. If no value is explicitly given then the timeout set globally for the connection will be used.
If true wait for the response.
true
Returns:
10384 10385 10386
# File 'lib/ovirtsdk4/services.rb', line 10384 def update(agent, opts = {}) internal_update(agent, Agent, UPDATE, opts) end